clear all 
clc

addpath(genpath('./sim_data_funcs'))
%mex './src/smooth_fixed_k_spotvol.cpp'
%mex './src/smooth_fixed_k_spotvol_jumps.cpp'
%mex './src/smooth_fixed_k_spotvol_intraday_jumps.cpp'

%% Experiment 1
sim_res_exp1 = sim_sv_data(22,1/390,-6.2,0.2,0,0.4,1992);

dXt = sim_res_exp1.dXt;
ct  = sim_res_exp1.ct;

Xt = cumsum(dXt);

DeltaXt = diff([0;Xt]);
nob     = length(DeltaXt);
k       =  5;
dt      = 1/390;

vol_est = splitapply(@(x)local_win_est_funs(x,k,dt), DeltaXt, ceil((1:nob)/k)');

plot(1:length(vol_est),vol_est,1:length(vol_est),ct(mod(1:nob,k)==1))


init_params = [5,20.5,1.5,0,100,2,...
    std(log(vol_est))^2*(1-0.99^2),...
    0.99,-6,...
    (0.4^2*dt)*(1-(1-0.2*dt)^(2*(k+1)))/(1-(1-0.2*dt)^2)
    ]';


%MCMC for smoothing
[PostParams, PostSpotVols] = smooth_fixed_k_spotvol(log(vol_est)+log(k),init_params,1000000,100000,200,1992);

%demo
est_true_smooth_vol_mat = zeros(length(vol_est),3);
est_true_smooth_vol_mat(:,1) = vol_est; %nonparametric estimation of volatility
tmp_ct = ct(mod(1:nob,k)==1);
est_true_smooth_vol_mat(:,2) = tmp_ct(1:length(vol_est));%true simulated volatility
est_true_smooth_vol_mat(:,3) = exp(mean(PostSpotVols))';%Bayesian smooht volatility

figure
plot(est_true_smooth_vol_mat(:,1),...
    'LineStyle','-','Color','b','LineWidth',1,'DisplayName','Estimated Volatility')
hold on
plot(est_true_smooth_vol_mat(:,2),...
    'LineStyle','-','Color','r','LineWidth',0.9,'DisplayName','Simulated Volatility')
hold on
plot(est_true_smooth_vol_mat(:,3),...
    'LineStyle','--','Color','c','LineWidth',0.75,'DisplayName','Smoothed Volatility')
legend('FontName','times')

