function sim_res = sim_sv_data(nod, delta, muh, kappa, rho, sigmah, iseed)

    nob = nod / delta; % total number of observations
    phi = 1-kappa*delta; % AR coefficient
    
    % randomness control
    rng(iseed)
    
    epsilon = randn(2*nob,1)*sqrt(delta)*sigmah;
    epsilonvol = randn(nob,1)*sqrt(delta);
    
    eta = epsilon(1:nob)*rho + epsilon((nob+1):(2*nob))*sqrt(1-rho^2);
    
    h = zeros(nob+1,1);
    h(1) = sqrt(delta*sigmah^2/(1-phi^2)) * randn(1); % initial condition for log vol dynaimcs

    for t = 2:nob+1
        h(t) = phi*h(t-1) + eta(t-1);
    end
    
    h = h + muh;
    
    dXt = exp(h(2:(nob+1))/2) .* epsilonvol(1:nob);
    ct  = exp(h(2:(nob+1)));
    
    sim_res.dXt = dXt;
    sim_res.ct  = ct;
    
    
end